/**
 * Meeting data model.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('models/meeting/meeting',
		['app',
		 'shared/urlcatalog',
		 'shared/keys',
		 'ember',
		 'models/user/user'],
		 function(Filmeet, UrlCatalog, Keys){
	/*
	 * Creating Filmeet.Meeting class based on Ember.Object
	 */
	Filmeet.Meeting = Ember.Object.extend({
		/** Meeting sid */
		sid: null,
		/** Meeting name */
		name: null,
		/** Meeting creator user sid */
		userSid: null,
		/** Chosen meeting film */
		filmName: null,
		/** Number of candidates */
		numberCandidates: null,
		/** Indicates if everybody has voted*/
		voted: false,
		/** In cinema films filtering */
		inCinema: false,
		/** Not seen films filtering */
		notSeen: false,
		/** Meeting date */
		date: null
	});
	/*
	 * Reopening class for coding static properties and functions
	 */
	Filmeet.Meeting.reopenClass({
		get: function(sid){
			var meeting = Filmeet.Meeting.create();
			$.ajax({
				type: 'GET',
				cache: false,
				url: UrlCatalog.get('getMeeting')+"/"+sid,
				data: {'hash': localStorage.getItem(Keys.authorizationHash)},
				dataType:'json',
				success: function(data){
					meeting.set('sid', data.sid);
					meeting.set('name', data.name);
					meeting.set('voted', data.voted);
					meeting.set('date', data.date);
					meeting.set('numberCandidates', data.numberCandidates);
					meeting.set('voted', data.voted);
					meeting.set('inCinema', data.inCinema);
					meeting.set('notSeen', data.notSeen);
				}
			});
			return meeting;
		},
		getAll: function(){
			var myMeetings = [];
			$.ajax({
				type: 'GET',
				cache: false,
				url: UrlCatalog.get('getAllMyMeetings'),
				data: {'userSid': localStorage.getItem(Keys.username), 'hash': localStorage.getItem(Keys.authorizationHash)},
				dataType:'json',
				success: function(data){
					data.forEach(function(meeting){
						myMeetings.addObject(Filmeet.Meeting.create({
							sid: meeting.sid,
							name: meeting.name,
							voted: meeting.voted,
							date: meeting.date
						}));
					});
				}
			});
			return myMeetings;
		},
		getAllMyNext: function(){
			var myNextMeetings = [];
			$.ajax({
				type: 'GET',
				cache: false,
				url: UrlCatalog.get('getAllMyNextMeetings'),
				data: {'userSid': localStorage.getItem(Keys.username), 'hash': localStorage.getItem(Keys.authorizationHash)},
				dataType:'json',
				success: function(data){
					data.forEach(function(meeting){
						myNextMeetings.addObject(Filmeet.Meeting.create({
							sid: meeting.sid,
							name: meeting.name,
							date: meeting.date
						}));
					});
				}
			});
			return myNextMeetings;
		}
	});
});